Write

Struct Write 

pub struct Write { /* private fields */ }
A client for BigQuery Storage Write API.

Implementations

Source

impl Write

pub fn builder() -> ClientBuilder

Creates a new ClientBuilder.

pub fn open_default_streamInto<String>>( &self, table: T, ) -> WriterBuilder<DefaultStream>

Opens the default stream for the given table.

table must have the format projects/{project}/datasets/{dataset}/tables/{table}.

Example
let writer = client
    .open_default_stream("projects/my-project/datasets/my-dataset/tables/my-table")
    .build_arrow(schema())
    .await?;

use google_cloud_bigquery::model::ArrowSchema;
fn schema() -> ArrowSchema {
  todo!("Define your table's schema...")
}
pub fn create_streamApplicationCreatedStream, T: Into<String>>( &self, table: T, ) -> WriterBuilder

Creates a new application-created stream for the given table.

table must have the format projects/{project}/datasets/{dataset}/tables/{table}.

The stream type S can be inferred from the variable’s writer type annotation (PendingWriter, CommittedWriter, or BufferedWriter) or specified explicitly via turbofish (create_stream::(...)).

See Selecting a type for guidance on choosing a stream type for your workload.

Example
use google_cloud_bigquery::write::PendingWriter;
use google_cloud_bigquery::write::format::Arrow;
let writer: PendingWriter = client
    .create_stream("projects/my-project/datasets/my-dataset/tables/my-table")
    .build_arrow(schema())
    .await?;

use google_cloud_bigquery::model::ArrowSchema;
fn schema() -> ArrowSchema {
  todo!("Define your table's schema...")
}
pub fn attach_to_streamApplicationCreatedStream, T: Into<String>>( &self, write_stream: T, ) -> WriterBuilder

Attaches a writer to an existing application-created stream.

write_stream must have the format projects/{project}/datasets/{dataset}/tables/{table}/streams/{stream}.

The stream type S can be inferred from the variable’s writer type annotation (PendingWriter, CommittedWriter, or BufferedWriter) or specified explicitly via turbofish (attach_to_stream::(...)).

Example
use google_cloud_bigquery::write::CommittedWriter;
use google_cloud_bigquery::write::format::Arrow;
let writer: CommittedWriter = client
    .attach_to_stream("projects/my-project/datasets/my_dataset/tables/my_table/streams/my_stream")
    .build_arrow(schema())
    .await?;